rm(list=ls(all=TRUE))
library(matiming)
library(xtable)
library(zoo)

# access the data
data <- sp500.monthly
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]

# simulate the trading strategies
tc <- 0.0025
fast <- 1:5
slow <- 2:15
final <- 2:10
shorts <- F
res1 <- sim.mac.strategy(totret=totret, rfret=rfret, dates=dates,
                         capret=capret, tc=tc, shorts=shorts, fast=fast, slow=slow, FUN=SMA)
res2 <- sim.mom.strategy(totret=totret, rfret=rfret, dates=dates,
                         capret=capret, tc=tc, shorts=shorts, winsize=slow)
results <- sim.results.merge(res1, res2)

# find the best in-sample strategies
start.date <- as.Date("1920-01-01", format="%Y-%m-%d")
end.date <- as.Date("2015-12-31", format="%Y-%m-%d")
res <- back.test(results, start.date, end.date)

# print out the best strategies in the back test and plot cumulative returns
df <- best.is.strategies(res, to.annual=sqrt(12), plot.results=TRUE)
xtab <- xtable(df, digits=3)
print(xtab, include.rownames=FALSE)

# print out the descriptive statistics of the best trading strategy
df <- descriptive.statistics(res)
xtab <- xtable(df, digits=2)
print(xtab)

# plot the rolling outperformance
start.date <- as.Date("1925-01-01", format="%Y-%m-%d")
split.date <- as.Date("1929-12-31", format="%Y-%m-%d")
end.date <- as.Date("2015-12-31", format="%Y-%m-%d")
is.outperformance.plot(res, start.date=start.date, split.date=split.date,
 end.date=end.date)
