rm(list=ls(all=TRUE))
library(matiming)
library(zoo)
library(xtable)

# access the data
data <- sp500.monthly
dates <- index(data)
data <- coredata(data)
capret <- data[,"CAP"]
totret <- data[,"TOT"]
rfret <- data[,"RF"]

# simulate the trading strategies
tc <- 0.0025
fast <- 1:8
slow <- 2:18
shorts <- F
res1 <- sim.mac.strategy(totret=totret, rfret=rfret, dates=dates,
                         capret=capret, tc=tc, shorts=shorts, fast=fast, slow=slow, FUN=SMA)
res2 <- sim.mom.strategy(totret=totret, rfret=rfret, dates=dates,
                         capret=capret, tc=tc, shorts=shorts, winsize=slow)
results <- sim.results.merge(res1, res2)

# simulate the out-of-sample trading strategy using the rolling in-sample window
start.date <- as.Date("1920-01-01", format="%Y-%m-%d")
end.is.date <- as.Date("1949-12-31", format="%Y-%m-%d")
end.oos.date <- as.Date("2015-12-31", format="%Y-%m-%d")
refit.every <- 1
rolling <- TRUE
res <- forward.test(results, start.date, end.is.date, end.oos.date,
                        refit.every=refit.every, rolling=rolling, FUN=Sharpe)

# report the descriptive statistics, the p-value of the test, and plot the results
df <- descriptive.statistics(res, plot.results = TRUE)
xtab <- xtable(df, digits=2)
print(xtab)

# plot the rolling outperformance
start.date <- as.Date("1950-01-01", format="%Y-%m-%d")
split.date <- as.Date("1954-12-31", format="%Y-%m-%d")
end.date <- as.Date("2015-12-31", format="%Y-%m-%d")

oos.outperformance.plot(res, start.date=start.date, split.date=split.date,
                        end.date=end.date)

